@props(['title' => ''])

<html lang="{{ str_replace('_', '-', app()->getLocale()) }}" dir="{{ __('app.direction') ?? 'ltr' }}">

<head>
    <meta charset="UTF-8">
    <meta http-equiv="X-UA-Compatible" content="ie=edge">
    <meta name="viewport" content="width=device-width, initial-scale=1">
    <meta name="csrf-token" content="{{ csrf_token() }}">
    <title>{{ $title ?? '' }} :: {{ __('app.app_name') }}</title>
    <link rel="apple-touch-icon" sizes="180x180" href="/assets/favicon/apple-touch-icon.png">
    <link rel="icon" type="image/png" sizes="32x32" href="/assets/favicon/favicon-32x32.png">
    <link rel="icon" type="image/png" sizes="16x16" href="/assets/favicon/favicon-16x16.png">
    <link rel="manifest" href="/assets/favicon/site.webmanifest">
    <meta name="msapplication-TileColor" content="#da532c">
    <meta name="theme-color" content="#ffffff">
    <link rel="preconnect" href="https://fonts.googleapis.com">
    <link rel="preconnect" href="https://fonts.gstatic.com" crossorigin="">
    <link
        href="https://fonts.googleapis.com/css2?family=Almarai:wght@300;400;700;800&amp;family=Tajawal:wght@200;300;400;500;700;800;900&amp;display=swap"
        rel="stylesheet">
    @livewireStyles
    @stack('cssLibs')
    @vite(['resources/css/app.scss'], 'build/frontend')
    @stack('styles')
    <style>
        .preloader {
            position: fixed;
            top: 0;
            left: 0;
            margin: auto;
            width: 100vw;
            height: 100vh;
            background-color: rgba(0, 59, 33);
            opacity: 1;
            -webkit-transition: all 0.3s ease;
            -moz-transition: all 0.3s ease;
            transition: all 0.3s ease;
            transition-duration: 500ms;
            -webkit-transition-duration: 500ms;
            transition-timing-function: cubic-bezier(0.86, 0, 0.07, 1);
            -webkit-transition-timing-function: cubic-bezier(0.86, 0, 0.07, 1);
            z-index: 9999;
            transition-delay: 0.65s;
        }

        .preloader * {
            -webkit-transition: all 0.3s ease;
            -moz-transition: all 0.3s ease;
            transition: all 0.3s ease;
            transition-duration: 500ms;
            -webkit-transition-duration: 500ms;
            transition-timing-function: cubic-bezier(0.86, 0, 0.07, 1);
            -webkit-transition-timing-function: cubic-bezier(0.86, 0, 0.07, 1);
        }

        .preloader:before {
            content: "";
            width: 0;
            height: 0;
            border-style: solid;
            border-width: 0 200px 100vh 0;
            border-color: transparent #282828 transparent transparent;
            position: absolute;
            left: -200px;
            top: 0;
        }

        .preloader:after {
            content: "";
            width: 0;
            height: 0;
            border-style: solid;
            border-width: 100vh 0 0 200px;
            border-color: transparent transparent transparent rgba(0, 59, 33, 0.279);
            position: absolute;
            right: -200px;
            top: 0;
        }

        .preloader .inner {
            width: 100vw;
            height: 100vh;
            display: flex;
            flex-wrap: wrap;
            align-items: center;
            justify-content: center;
            overflow: hidden;
        }

        .preloader .inner .logo {
            display: inline-block;
            margin: 0;
            animation: fadeInUp ease 0.6s;
        }

        .preloader .inner .logo img {
            height: 75px;
        }

        .preloader .inner .percentage {
            width: 100%;
            font-size: 30vh;
            line-height: 1;
            font-weight: 800;
            color: #fff;
            position: absolute;
            top: 50%;
            transform: translateY(-50%);
            text-align: center;
            opacity: 0.05;
            transition-delay: 0.1s;
        }

        .page-loaded.preloader {
            left: calc(-100% - 200px);
            visibility: hidden;
        }

        .page-loaded.preloader .logo {
            transform: translateX(-100px);
            opacity: 0;
        }

        .page-loaded.preloader .percentage {
            margin-left: 100px;
            opacity: 0;
        }

        [x-cloak] {
            display: none !important;
        }
    </style>
</head>

<body x-cloak class="bg-gray-100 overflow-x-hidden" x-data x-init="$nextTick(() => {
    window.onload = function() {
        {{-- document.body.classList.add('loaded'); --}}
        document.querySelectorAll('.scroll-to').forEach(function(link) {
            link.addEventListener('click', function(e) {
                // prevent default behavior
                e.preventDefault();
                // grab the href attribute
                var id = link.getAttribute('href');
                $scroll(id, { offset: 0 });
                var sidebar = document.querySelector('.sidebar');
                sidebar.classList.remove('opened');
            });
        });
    }
    if (window.location.hash) {
        $scroll(window.location.hash, { offset: 1 });
        history.replaceState(null, null, ' ');
    }
})">
    {{ $slot }}
    <script>
        window.addEventListener('load', function() {
            var obj = document.querySelector('.preloader'),
                inner = document.querySelector('.inner .percentage'),
                page = document.querySelector('body');
            obj.classList.remove('page-loaded');
            page.classList.add('page-loaded');
            var w = 0,
                t = setInterval(function() {
                    w = w + 1;
                    inner.textContent = w;
                    if (w === 100) {
                        obj.classList.add('page-loaded');
                        page.classList.remove('page-loaded');
                        clearInterval(t);
                        w = 0;
                        page.classList.add('loaded');
                    }
                }, 20);
        });
    </script>
    @livewireScripts

    @vite(['resources/js/app.js'], 'build/frontend')

    @stack('jsLibs')
    @stack('scripts')

</body>

</html>
